/*    REPLICATION NOTES  
Date:        		28 December 2016
Code Version:		Final Version
Author:      		Findley, Milner, Nielson
Purpose:     		These files reproduce all results reported in our manuscript
Manuscript	:		Paper: "Foreign Aid Provision MlBl Paper_final_28Dec2016.doc"					
					Append: "Foreign Aid Provision MlBl Appendix_final_28Dec2016.docx"
Data Used:   		Primary data collected by authors
File Names:   		"rio_replication_final_28dec2016.do" (file that estimates the models reported in paper)
Input Files:		"Merged Survey.dta"
Machine:     		MGF; Macbook
Version:			Stata 14.2
Replication:		Materials will be available at http://michael-findley.com and through the journal website
*/


clear
set more off 

cd "SET PATH HERE"

set mem 500m

use "Merged Survey.dta"


********************************************************************************
********************************************************************************
*DATA PREP: Quietly
********************************************************************************
********************************************************************************

qui{
drop if lc == 1

*update the "express support" test to be the "strong support" test
gen strong_supp = .
replace strong_supp = 1 if exp == 4
replace strong_supp = 0 if exp == 1
replace strong_supp = 0 if exp == 2
replace strong_supp = 0 if exp == 3

*gen multilat/bilat for MPs and Masses
*multibilat_condition = 0 = control
*multibilat_condition = 1 = multilateral
*multibilat_condition = 2 = bilateral
*multi_bi = 1 = multi; = 2 = bilat
gen multibilat_condition=0 if donor_rand==7
replace multibilat_condit = multi_bi if multi_bi~=.

*create a variable for know + multibilat comp/used 
*can only use this for masses b/c we didn't ask manipulation check of MPs
gen got_know_mb_comp=.
replace got_know_mb_comp=0 if got_wb==1 | got_adb==1 /*| donor_rand==5*/
replace got_know_mb_comp=1 if got_us==1 | got_china==1 /*| donor_rand==6*/
ta got_know_mb_comp
ta  multi_bi got_know_mb_comp, miss
}

egen dvsum= rowtotal(strong_supp tell_support sign_pet enum_petition sms_willing sms) , missing
egen dvsum_mp= rowtotal(strong_supp tell_support sign_pet enum_petition pres_sign enum_pres tell_constits rally_locals coor_peers) , missing
replace dvsum = . if mass~=1
replace dvsum_mp = . if mp~=1

*** WASTE AND NEED
 tab aid_waste if mass==1 /* add 1&2 for ML and 4&5 for BL */
 tab aid_matchneed if mass==1 /* add 1&2 for ML and 4&5 for BL */

** Know donors & MPs
tab us_know if mass==1
tab china_know if mass==1
tab heard_adb if mass==1
tab heard_wb if mass==1

tab1 know_mp know_womanmp


/*************************
* Main Paper Results
*************************/

*** Table 1: Summary Statistics on Outcome Variables
summ strong_supp tell_support sign_pet enum_petition sms_willing if mass==1 & multi_bi~=.
sum sms  if have_phone == 1 & mass==1 & multi_bi~=.
sum dvsum if mass==1 & multi_bi~=.

summ strong_supp tell_support sign_pet enum_petition pres_sign enum_pres tell_constits rally_locals coor_peers if mp==1 & multi_bi~=.
sum dvsum_mp if mp==1 & multi_bi~=.

*** Table 2: Composition of the Sample vs. the 9th Ugandan Parliament

*** Table 3: Basic Results from MP and Mass Surveys.
*Panel A: MP and Citizen Outcomes
*Masses
ttest strong_supp if mass==1, by(multi_bi) unequal 
ttest tell_support if mass==1, by(multi_bi) unequal
ttest sign_pet if mass==1, by(multi_bi) unequal 
ttest enum_petition if mass==1, by(multi_bi) unequal
ttest sms_willing if mass==1, by(multi_bi) unequal
ttest sms  if have_phone == 1 & mass==1 , by(multi_bi) unequal
ttest dvsum if mass==1, by(multi_bi) unequal 

* MPs
ttest strong_supp if mp==1, by(multi_bi) unequal 
ttest tell_support if mp==1, by(multi_bi) unequal
ttest sign_pet if mp==1, by(multi_bi) unequal 
ttest enum_petition if mp==1, by(multi_bi) unequal
ttest pres_sign if mp==1, by(multi_bi) unequal
ttest enum_pres if mp==1, by(multi_bi) unequal
ttest dvsum_mp if mp==1, by(multi_bi) unequal

*Panel B: Elite Only Outcomes
*MPs
ttest tell_constits if mp==1, by(multi_bi) unequal
ttest rally_locals if mp==1, by(multi_bi) unequal
ttest coor_peers if mp==1, by(multi_bi) unequal


** Donor
** got_know_uschina_comp = 0 = China; 1 = U.S.
qui {
gen got_know_uschina_comp=.
replace got_know_uschina_comp=0 if got_china==1 
replace got_know_uschina_comp=1 if got_us==1
}

*** Table 4: : Citizen Preferences for American vs. Chinese Aid
ttest strong_supp if mass==1, by(got_know_uschina_comp) unequal
ttest tell_support if mass==1, by(got_know_uschina_comp) unequal
ttest sign_pet if mass==1, by(got_know_uschina_comp) unequal 
ttest enum_petition if mass==1, by(got_know_uschina_comp) unequal
ttest sms_willing if mass==1, by(got_know_uschina_comp) unequal
ttest sms  if have_phone == 1 & mass==1, by(got_know_uschina_comp) unequal
ttest dvsum if mass==1, by(got_know_uschina_comp) unequal


*** Tables 5-6
** multi_bi = 1 = ML, 2 = BL

** politicalization
** 1/2 = neediest; 4/5=allies
gen allies_help = cond(inlist(aid_allies,1,2),0,cond(inlist(aid_allies,4,5),1,.))
** 0 = neediest, 1 = allies

** transparency
** 1/2 = ML; 4/5=BL
gen mb_transp = cond(inlist(aid_transparent,1,2),0,cond(inlist(aid_transparent,4,5),1,.))
** 0 = ML, 1 = BL
** efficacy (aid_waste)
** 1/2 = ML; 4/5=BL
gen mb_waste = cond(inlist(aid_waste,1,2),0,cond(inlist(aid_waste,4,5),1,.))
** 0 = ML, 1 = BL

** match need
gen matchneed =  cond(inlist(aid_matchneed,1,2),1,cond(inlist(aid_matchneed,4,5),0,.))

*** Table 5: Mass Support and Aid Support: Respondents knowing donor
** politicalization
** helps neediest
ttest dvsum if mass==1 & allies_help==0 & got_know_mb_comp~=. , by(multi_bi) unequal unpaired
** Helps allies
ttest dvsum if mass==1 & allies_help==1 & got_know_mb_comp~=. , by(multi_bi) unequal unpaired

*** conditionality
** aid_conds_help : 0 = hurt 1 = help
** conditions hurt
ttest dvsum if mass==1 & aid_conds_help==0 & got_know_mb_comp~=. , by(multi_bi) unequal unpaired
** conditions help
ttest dvsum if mass==1 & aid_conds_help==1 & got_know_mb_comp~=. , by(multi_bi) unequal unpaired

** transparency
** 1/2 = ML; 4/5=BL
** bilateral
ttest dvsum if mass==1 & mb_transp==1 & got_know_mb_comp~=. , by(multi_bi) unequal unpaired
** multilateral
ttest dvsum if mass==1 & mb_transp==0 & got_know_mb_comp~=. , by(multi_bi) unequal unpaired

** efficacy (aid_waste) 
** 1/2 = ML; 4/5=BL
** bilateral
ttest dvsum if mass==1 & mb_waste==1 & got_know_mb_comp~=. , by(multi_bi) unequal unpaired
** multilateral
ttest dvsum if mass==1 & mb_waste==0 & got_know_mb_comp~=., by(multi_bi) unequal unpaired

*** alignment
** bilateral
ttest dvsum if mass==1 & matchneed==0 & got_know_mb_comp~=. , by(multi_bi) unequal 
** multilateral
ttest dvsum if mass==1 & matchneed==1 & got_know_mb_comp~=., by(multi_bi) unequal 


*** Table 6: MP Support and Aid Support
* MPs
** politicalization
** helps neediest
ttest dvsum_mp if mp==1 & allies_help==0, by(multi_bi) unequal
** Helps allies
ttest dvsum_mp if mp==1 & allies_help==1, by(multi_bi) unequal

** conditionality
** conditions hurt
ttest dvsum_mp if mp==1 & aid_conds_help==0, by(multi_bi) unequal unpaired
** conditions help
ttest dvsum_mp if mp==1 & aid_conds_help==1, by(multi_bi) unequal unpaired

** transparency
** 1/2 = ML; 4/5=BL
** bilateral
ttest dvsum_mp if mp==1 & mb_transp==0, by(multi_bi) unequal unpaired
** multilateral
ttest dvsum_mp if mp==1 & mb_transp==1, by(multi_bi) unequal unpaired

** efficacy (aid_waste)
** 1/2 = ML; 4/5=BL
** bilateral
ttest dvsum_mp if mp==1 & mb_waste==1, by(multi_bi) unequal unpaired
** multilateral
ttest dvsum_mp if mp==1 & mb_waste==0, by(multi_bi) unequal unpaired

*** alignment
** bilateral
ttest dvsum_mp if mp==1 & matchneed==0, by(multi_bi) unequal
** multilateral
ttest dvsum_mp if mp==1 & matchneed==1, by(multi_bi) unequal


* citizen trust
*trust_multilat = IMF, World Bank, UNDP, and ADB
*trust_multilat2= World Bank, UNDP, and ADB
*trust_bilat = China and the U.S.
qui {
gen trust_multilat = .
gen trust_bilat = .
gen trust_multilat2 = .

replace trust_multilat = (trust_imf + trust_wb + trust_undp + trust_adb) / 4
replace trust_multilat2 = (trust_wb + trust_undp + trust_adb) / 3
replace trust_bilat = (trust_china + trust_us) / 2
}

*** Table 7: Citizen Trust Levels for Domestic versus International Institutions.
ttest trust_wb=trust_us if mass==1, unpaired
ttest trust_undp=trust_us if mass==1, unpaired
ttest trust_adb=trust_us if mass==1, unpaired
ttest trust_multilat2=trust_us if mass==1, unpaired

ttest trust_wb=trust_china if mass==1, unpaired
ttest trust_undp=trust_china if mass==1, unpaired
ttest trust_adb=trust_china if mass==1, unpaired
ttest trust_multilat2=trust_china if mass==1, unpaired

ttest trust_wb=trust_bilat if mass==1, unpaired
ttest trust_undp=trust_bilat if mass==1, unpaired
ttest trust_adb=trust_bilat if mass==1, unpaired
ttest trust_multilat2=trust_bilat if mass==1, unpaired


*** Table 8: Survey Outcome Results for Multilateral vs. Bilateral Aid.
ttest  trust_mult~t ==trust_bilat if mass==1 , unpaired
ttest   multilat_trans==bilat_trans if mass==1 , unpaired
ttest   multilat_trans==bilat_trans if mp==1 , unpaired

/*******************************
*Replication for APPENDIX:
*********************************/

*** APPENDIX - By question (MPs and all mass respondents)

** Table A2: Citizen Preferences for Bilateral vs. Multilateral Aid For those Who Know Donor.
ttest strong_supp if mass==1, by(got_know_mb_comp) unequal /* Numbers in paper */
ttest tell_support if mass==1, by(got_know_mb_comp) unequal
ttest sign_pet if mass==1, by(got_know_mb_comp) unequal 
ttest enum_petition if mass==1, by(got_know_mb_comp) unequal
ttest sms_willing if mass==1, by(got_know_mb_comp) unequal
ttest sms  if have_phone == 1 & mass==1 , by(got_know_mb_comp) unequal
ttest dvsum if mass==1, by(got_know_mb_comp) unequal 

*CACE analysis: Panel B (Instrument: Assingment to Treat/Know donor)
preserve
gen aid_control = abs(treat_control-2)
order treat_control aid_control
gen manip_mb = .

*guessed multilat
replace manip_mb = 0 if manip_2 == 1 | manip_2 == 2 | manip_2 == 5
*guessed govt 
replace manip_mb = 1 if manip_2 == 3 | manip_2 == 4 | manip_2 == 6

ivregress 2sls strong_supp (manip_mb=got_know_mb_comp) if mass == 1, robust
ivregress 2sls tell_support   (manip_mb=got_know_mb_comp) if mass == 1, robust
ivregress 2sls sign_pet  (manip_mb=got_know_mb_comp) if mass == 1, robust
ivregress 2sls enum_petition  (manip_mb=got_know_mb_comp) if mass == 1, robust
ivregress 2sls sms_willing  (manip_mb=got_know_mb_comp) if mass == 1, robust
ivregress 2sls sms (manip_mb=got_know_mb_comp) if mass == 1 & have_phone == 1, robust
ivregress 2sls dvsum (manip_mb=got_know_mb_comp) if mass == 1, robust

restore 

** Table A3: Mass Support and Aid Politicization
** 1/2 = neediest; 4/5=allies
** 0 = neediest, 1 = allies
** multi_bi = 1 = ML, 2 = BL

** Helps neediest
ttest strong_supp if mass==1 & allies_help==0 , by(multi_bi) unequal 
ttest tell_support if mass==1 & allies_help==0 , by(multi_bi) unequal
ttest sign_pet if mass==1 & allies_help==0 , by(multi_bi) unequal 
ttest enum_petition if mass==1 & allies_help==0 , by(multi_bi) unequal
ttest sms_willing if mass==1 & allies_help==0 , by(multi_bi) unequal
ttest sms  if have_phone == 1 & mass==1 & allies_help==0  , by(multi_bi) unequal
ttest dvsum if mass==1 & allies_help==0 , by(multi_bi) unequal 

** Helps allies
ttest strong_supp if mass==1 & allies_help==1, by(multi_bi) unequal 
ttest tell_support if mass==1 & allies_help==1 , by(multi_bi) unequal
ttest sign_pet if mass==1 & allies_help==1 , by(multi_bi) unequal 
ttest enum_petition if mass==1 & allies_help==1 , by(multi_bi) unequal
ttest sms_willing if mass==1 & allies_help==1 , by(multi_bi) unequal
ttest sms  if have_phone == 1 & mass==1 & allies_help==1  , by(multi_bi) unequal
ttest dvsum if mass==1 & allies_help==1, by(multi_bi) unequal 


*** Table A4: Mass Support and Aid Conditionality
** aid_conds_help : 0 = hurt 1 = help
** multi_bi = 1 = ML, 2 = BL
** CONDITIONS HURT
ttest strong_supp if mass==1 & aid_conds_help==0 , by(multi_bi) unequal 
ttest tell_support if mass==1 & aid_conds_help==0 , by(multi_bi) unequal
ttest sign_pet if mass==1 & aid_conds_help==0 , by(multi_bi) unequal 
ttest enum_petition if mass==1 & aid_conds_help==0 , by(multi_bi) unequal
ttest sms_willing if mass==1 & aid_conds_help==0 , by(multi_bi) unequal
ttest sms  if have_phone == 1 & mass==1 & aid_conds_help==0  , by(multi_bi) unequal
ttest dvsum if mass==1 & aid_conds_help==0 , by(multi_bi) unequal 

** CONDITIONS HELP
ttest strong_supp if mass==1 & aid_conds_help==1, by(multi_bi) unequal 
ttest tell_support if mass==1 & aid_conds_help==1 , by(multi_bi) unequal
ttest sign_pet if mass==1 & aid_conds_help==1 , by(multi_bi) unequal 
ttest enum_petition if mass==1 & aid_conds_help==1 , by(multi_bi) unequal
ttest sms_willing if mass==1 & aid_conds_help==1 , by(multi_bi) unequal
ttest sms  if have_phone == 1 & mass==1 & aid_conds_help==1  , by(multi_bi) unequal
ttest dvsum if mass==1 & aid_conds_help==1, by(multi_bi) unequal 


*Table A5: Mass Support and Aid Transparency.
** transparency
** 1/2 = ML; 4/5=BL
** 0 = ML, 1 = BL
** multi_bi = 1 = ML, 2 = BL

** Bilateral
ttest strong_supp if mass==1 & mb_transp==1, by(multi_bi) unequal 
ttest tell_support if mass==1 & mb_transp==1 , by(multi_bi) unequal
ttest sign_pet if mass==1 & mb_transp==1 , by(multi_bi) unequal 
ttest enum_petition if mass==1 & mb_transp==1 , by(multi_bi) unequal
ttest sms_willing if mass==1 & mb_transp==1 , by(multi_bi) unequal
ttest sms  if have_phone == 1 & mass==1 & mb_transp==1  , by(multi_bi) unequal
ttest dvsum if mass==1 & mb_transp==1 , by(multi_bi) unequal unpaired

** Multilateral
ttest strong_supp if mass==1 & mb_transp==0 , by(multi_bi) unequal 
ttest tell_support if mass==1 & mb_transp==0 , by(multi_bi) unequal
ttest sign_pet if mass==1 & mb_transp==0 , by(multi_bi) unequal 
ttest enum_petition if mass==1 & mb_transp==0 , by(multi_bi) unequal
ttest sms_willing if mass==1 & mb_transp==0 , by(multi_bi) unequal
ttest sms  if have_phone == 1 & mass==1 & mb_transp==0  , by(multi_bi) unequal
ttest dvsum if mass==1 & mb_transp==0 , by(multi_bi) unequal 


*Table A6: Mass Support and Aid Efficacy
** efficacy (aid_waste)
** 1/2 = ML; 4/5=BL
** 0 = ML, 1 = BL
** multi_bi = 1 = ML, 2 = BL

** Bilateral
ttest strong_supp if mass==1 & mb_waste==1, by(multi_bi) unequal 
ttest tell_support if mass==1 & mb_waste==1 , by(multi_bi) unequal
ttest sign_pet if mass==1 & mb_waste==1 , by(multi_bi) unequal 
ttest enum_petition if mass==1 & mb_waste==1 , by(multi_bi) unequal
ttest sms_willing if mass==1 & mb_waste==1 , by(multi_bi) unequal
ttest sms  if have_phone == 1 & mass==1 & mb_waste==1  , by(multi_bi) unequal
ttest dvsum if mass==1 & mb_waste==1 , by(multi_bi) unequal unpaired

** Multilateral
ttest strong_supp if mass==1 & mb_waste==0 , by(multi_bi) unequal 
ttest tell_support if mass==1 & mb_waste==0 , by(multi_bi) unequal
ttest sign_pet if mass==1 & mb_waste==0 , by(multi_bi) unequal 
ttest enum_petition if mass==1 & mb_waste==0 , by(multi_bi) unequal
ttest sms_willing if mass==1 & mb_waste==0 , by(multi_bi) unequal
ttest sms  if have_phone == 1 & mass==1 & mb_waste==0  , by(multi_bi) unequal
ttest dvsum if mass==1 & mb_waste==0 , by(multi_bi) unequal 


*** Table A7: Randomization Check (Mass Survey) 
gen donor_treat = multi_bi
recode donor_treat (1=0) (2=1)

gen christian=.
replace christian=1 if religion==1 | religion==2 | religion==5 | religion==6
replace christian=0 if religion==3 | religion==4
*nois ta christian

gen muslim=.
replace muslim=1 if religion ==3
replace muslim=0 if religion==1 | religion==2 | religion==4 | religion==5 | religion==6
*nois ta muslim, mis

logit donor_treat education male age nrm christian muslim region_east region_west region_north if mass == 1 & age>1, robust




